pub struct Example {
pub role: Role,
pub content: Option<String>,
pub name: Option<String>,
pub function_call: Option<FunctionCall>,
}Expand description
Example of a message involved in a function calling process
Fields
role: RoleSame as the role in Message, can be “user”, “assistant”, or “function”.
content: Option<String>Dialog content instructions: (1) If the current message contains a function_call and the role is “assistant”, the message can be empty. However, in other scenarios, it cannot be empty. (2) The content corresponding to the last message cannot be a blank character, including spaces, “\n”, “\r”, r“\f“, etc.
name: Option<String>The “author” of the message. the This member is required when the role value is “function”, and in this case is should be the name in the function_call in the response content
function_call: Option<FunctionCall>this is function calling result of last round of function call, serving as chat history.