pub struct Function {
pub name: String,
pub description: String,
pub parameters: RootSchema,
pub response: Option<RootSchema>,
pub examples: Option<Vec<Vec<Example>>>,
}Expand description
Definition of the function structure that some models(like Erniebot) can select and call.
Fields
name: StringThe name of the function.
description: StringThe description of the function.
parameters: RootSchemaThe format of parameters of the function, following the JSON schema format.
response: Option<RootSchema>The format of the response of the function, following the JSON schema format.
examples: Option<Vec<Vec<Example>>>The examples of the function. each instance of the outer vector represents a round of conversation, and each instance of the inner vector represents a message in the round of conversation. More details can be found in the example of chat_with_function.rs.