Message

Struct Message 

pub struct Message {
    pub role: Role,
    pub content: String,
    pub name: Option<String>,
    pub function_call: Option<FunctionCall>,
}
Definition of the message structure

as metioned in https://cloud.baidu.com/doc/WENXINWORKSHOP/s/jlil56u11, The “messages” member must not be empty. One member represents a single round of conversation, while multiple members represent multiple rounds of conversation. For example: (1) Example with one member: “messages”: [ {“role”: “user”, “content”: “Hello”}]

    use erniebot_rs::chat::{Message, Role};
    let message1 = Message {
        role: Role::User,
        content: "hello, I'm a user".to_string(),
        ..Default::default()
    };
    let messages = vec![message1];

(2) Example with three members:

    let message1 = Message {
        role: Role::User,
        content: "hello, I'm a user".to_string(),
        ..Default::default()
    };
    let message2 = Message {
        role: Role::Assistant,
        content: "hello, I'm a AI LLM model".to_string(),
        ..Default::default()
    };
    let message3 = Message {
        role: Role::User,
        content: "hello, I want you to help me".to_string(),
        ..Default::default()
    };
    let messages = vec![message1, message2, message3];

The last message is the current request information, while the previous messages are historical conversation information.

The number of members must be odd. The role values of the messages in the members are explained as follows: The role value of the message at odd positions must be either “user” or “function”, while the role value of the message at even positions must be “assistant”. The role of the first message cannot be “function”. For example:

In the example, the role values of the messages are “user”, “assistant”, “user”, “assistant”, and “user” respectively. The role values of the messages at odd positions are “user”, which means the role values of the 1st, 3rd, and 5th messages are “user”. The role values at even positions are “assistant”, which means the role values of the 2nd and 4th messages are “assistant”.

Fields

role: Role

The role of the message. The value can be “user”, “assistant”, or “function”(for some specific model).

content: String

The content of the message. The value is a string.

name: Option<String>

The “author” of the message. the This member is required when the role value is “function”, and in this case is should be the name in the function_call in the response content

function_call: Option<FunctionCall>

this is function calling result of last round of function call, serving as chat history.